@@ -9,12 +9,12 @@ int main(void) {
   // (2) Make a parser
   parser parser(R"(
         # Grammar for Calculator...
-        Additive    <- Multitive '+' Additive / Multitive
-        Multitive   <- Primary '*' Multitive^cond / Primary
+        Additive    <- Multiplicative '+' Additive / Multiplicative
+        Multiplicative   <- Primary '*' Multiplicative^cond / Primary
         Primary     <- '(' Additive ')' / Number
         Number      <- < [0-9]+ >
         %whitespace <- [ \t]*
-        cond <- '' { error_message "missing multitative" }
+        cond <- '' { error_message "missing multiplicative" }
     )");
 
   assert(static_cast<bool>(parser) == true);
@@ -22,16 +22,16 @@ int main(void) {
   // (3) Setup actions
   parser["Additive"] = [](const SemanticValues &vs) {
     switch (vs.choice()) {
-    case 0: // "Multitive '+' Additive"
+    case 0: // "Multiplicative '+' Additive"
       return any_cast<int>(vs[0]) + any_cast<int>(vs[1]);
-    default: // "Multitive"
+    default: // "Multiplicative"
       return any_cast<int>(vs[0]);
     }
   };
 
-  parser["Multitive"] = [](const SemanticValues &vs) {
+  parser["Multiplicative"] = [](const SemanticValues &vs) {
     switch (vs.choice()) {
-    case 0: // "Primary '*' Multitive"
+    case 0: // "Primary '*' Multiplicative"
       return any_cast<int>(vs[0]) * any_cast<int>(vs[1]);
     default: // "Primary"
       return any_cast<int>(vs[0]);
